//
// C++ Interface: kmfruletragetoptioneditinterface
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITINTERFACE_H
#define KMFRULETARGETOPTIONEDITINTERFACE_H

#include "kmfruleoptioneditinterface.h"

#include <tqstring.h>
#include <tqstringlist.h>

#include <tdemacros.h>

/**
@author Christian Hubinger
*/
namespace KMF {
class TDE_EXPORT KMFRuleTargetOptionEditInterface : public KMFRuleOptionEditInterface {
public:
	KMFRuleTargetOptionEditInterface(TQObject *parent = 0, const char *name = 0);

	virtual ~KMFRuleTargetOptionEditInterface();

	virtual bool manageTarget( const TQString& ) const;
	virtual bool setTarget( const TQString& ) = 0;

protected:
	TQStringList m_managedTargets;


};
}
#endif
